@@ -1,3 +1,4 @@
+from bergen.postmans.pika import PikaPostman
 from bergen.auths.legacy.app import LegacyApplication
 from bergen.auths.backend.app import ArnheimBackendOauth
 from bergen.auths.implicit.app import ImplicitApplication
@@ -31,6 +32,4 @@ class Bergen(BaseBergen, QueryMixIn, SubscribeMixIn):
         elif grant_type == GrantType.PASSWORD: auth = LegacyApplication(host=host, port=port, client_id=client_id, client_secret=client_secret, protocol="http", verify=True, **kwargs)
         else: raise NotImplementedError("Please Specifiy a valid Grant Type")
 
-        main_ward = SubscriptionGraphQLWard(host=host, port=port, protocol=protocol, token=auth.getToken())
-
-        super().__init__(auth, main_ward, auto_negotiate=True, bind=bind, **kwargs)
\ No newline at end of file
+        super().__init__(auth, host, port, protocol = protocol, auto_negotiate=True, bind=bind, **kwargs)
\ No newline at end of file
