@@ -1,5 +1,5 @@
 
-from bergen.schema import Assignation, Node, Provision, Transcript, VartPod, Volunteer
+from bergen.schema import Assignation, Node, Peasent, PeasentTemplate, Provision, Transcript, VartPod, Volunteer
 from bergen.query import TypedGQL
 
 
@@ -25,6 +25,10 @@ NEGOTIATION_GQL = TypedGQL("""
             type
         }
     }
+    postman {
+        type
+        kwargs
+    }
     points {
       host
       name
@@ -40,6 +44,27 @@ NEGOTIATION_GQL = TypedGQL("""
 
 
 
+SERVE_GQL = TypedGQL("""
+    mutation Serve($name: String!){
+        serve(name:$name){
+            id
+            name
+            
+        }
+    }
+""", Peasent)
+
+OFFER_GQL = TypedGQL("""
+    mutation Offer($node: ID!, $params: GenericScalar!, $peasent: ID!){
+        offer(node: $node, params: $params, peasent: $peasent ){
+            id
+            name 
+        }
+    }
+""", PeasentTemplate)
+
+
+
 
 VOLUNTEER_GQL = TypedGQL("""
         mutation Volunteer($nodeid: ID!, $name: String!, $version: String!){
