@@ -7,11 +7,6 @@ from typing import Type
 
 class NodeManager(ModelManager[Node]):
 
-
-    def get(self, ward=None, **kwargs) -> Node:
-        return NODE_QUERY(self.model).run(ward=ward, variables=kwargs)
-
-
     def get_or_create(self, inputs: Type[Inputs] = None, outputs: Type[Outputs] = None , **kwargs) -> Node:
         
         parsed_inputs = inputs.serialized
